==> light-ning-0.2.5.tgz: package/src/Router.js <==
import { middlewares, Response, capitalize } from './index';
import app from './index';

class Router {

  routesArray;
  rootPath;
  controllersPath;
  actionName;
  controllerName;

  setControllersPath(path) {
    this.controllersPath = path;
  }

  routes(rootPath, routes) {
    this.rootPath = rootPath;
    this.routesArray = routes;
  }

  route(req, res) {
    const {url, method} = req;

    this.routesArray.map(route => {
      route.method = route.method.toUpperCase();

      const response = new Response(res);

      const run = () => {
        if (route.middleWares && !route.action) {
          return middlewares(route.middleWares);
        } else if (route.middleWares && route.action) {
          throw new Error('params: action and middleWares cannot work together');
        }

        if (((url + '/') === `${this.rootPath}${route.path}` || url === `${this.rootPath}${route.path}`) && method === route.method) {
          const [name, action] = route.action.split('@');
          this.actionName = action;
          this.controllerName = name;
          let Controller;

          try {
            Controller = new (require(`${this.controllersPath}/${name}`).default);

            try {
              Controller = new (require(`${this.controllersPath}/${name}`));
            } catch(e) {
              throw new Error(`cannot find "${this.controllersPath}/${name}" in ${app.get('base')}`);
            }
          } catch(e) {}

          this.action(req, res, Controller[action], response);
        }
      };

      if (route.guard) return route.guard({ req: req, res: res, next: run, response: response });

      run();
    });
  }

  action(req, res, method, response) {

    try {
      method({ req: req, res: res, response: response });
    } catch(e) {
      throw new Error(`${this.actionName} not found in ${capitalize(this.controllerName)} controller`);
    }
  }

}

export default new Router();

==> light-ning-0.2.9.tgz: package/src/Router.js <==
import { Response } from './index';
import { capitalize } from './lib';
import middlewares from './middlewares';
import app from './index';

class Router {

  routesArray;
  rootPath;
  controllersPath;
  actionName;
  controllerName;

  setControllersPath(path) {
    this.controllersPath = path;
  }

  routes(rootPath, routes) {
    this.rootPath = rootPath;
    this.routesArray = routes;
  }

  route(req, res) {
    const {url, method} = req;

    this.routesArray.map(route => {
      route.method = route.method.toUpperCase();

      const response = new Response(res);

      const run = () => {
        if (route.middleWares && !route.action) {
          return middlewares(route.middleWares);
        } else if (route.middleWares && route.action) {
          throw new Error('params: action and middleWares cannot work together');
        }

        if (((url + '/') === `${this.rootPath}${route.path}` || url === `${this.rootPath}${route.path}`) && method === route.method) {
          const [name, action] = route.action.split('@');
          this.actionName = action;
          this.controllerName = name;
          let Controller;

          try {
            Controller = new (require(`${this.controllersPath}/${name}`).default);
          } catch(e) {
            try {
              Controller = new (require(`${this.controllersPath}/${name}`));
            } catch(e) {
              throw new Error(`${capitalize(this.controllerName)} controller contains error or cannot find "${this.controllersPath}/${name}" in ${app.get('base')}`);
            }
          }

          this.action(req, res, Controller[action].bind(Controller), response);
        }
      };

      if (route.guard) return route.guard({ req: req, res: res, next: run, response: response });

      run();
    });
  }

  action(req, res, method, response) {
    method({ req: req, res: res, response: response });
  }

}

export default new Router();
